@@ -14,6 +14,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -161,7 +165,7 @@ static GtkTargetEntry button_drag_types[] = {
 static gint n_button_drag_types = 2;
 
 
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_DriveMountApplet_Factory",
+PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_DriveMountApplet_Factory", PANEL_TYPE_APPLET,
 			     "Drive-Mount-Applet", "0", applet_factory, NULL)
 
 static gboolean
