@@ -26,6 +26,10 @@
  * USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <X11/keysym.h>
 #include <X11/Xmd.h>
 #include <X11/Xlib.h>
