@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "modemlights.h"
 #include <panel-applet.h>
 #include "digits.xpm"
@@ -1530,6 +1534,7 @@ modemlights_applet_factory (PanelApplet *applet,
 }
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_ModemLightsApplet_Factory",
+			     PANEL_TYPE_APPLET,
 			     "Modemlights applet",
 			     "0",
 			     modemlights_applet_factory,
